{% load staticfiles %}
<!DOCTYPE html>
<html>
  <head>
    <title>Cross Triangulaire X-Centrale Supélec-HEC</title>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="{% static "crossix/css/styles.css" %}">
  </head>

  <body>
    {% block content %}
    {% endblock %}
    <p>
    <a href="{% url 'index' %}">Accueil</a>
    |
    <a href="{% url 'register' %}">Inscription</a>
    |
    <a href="{% url 'list' %}">Liste des inscrits</a>
    |
    <a href="{% url 'access' %}">Accès</a>
    </p>
    <script src="{% static "crossix/js/app.js" %}"></script>
    {% block extrajs %}{% endblock %}
  </body>
</html>
